"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const definition_1 = require("../common/definition");
const commonFlags = require("../common/flags");
class Read extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Read);
        const { definition } = args;
        const { dereference, validate } = flags;
        let document;
        try {
            document = await definition_1.parseDefinition({ definition, dereference, validate });
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        const format = flags.format === 'json' || flags.json ? definition_1.OutputFormat.JSON : definition_1.OutputFormat.YAML;
        this.log(definition_1.stringifyDocument({ document, format }));
    }
}
Read.description = 'read, parse and convert OpenAPI definitions';
Read.examples = [
    '$ openapi read https://raw.githubusercontent.com/OAI/OpenAPI-Specification/master/examples/v3.0/petstore.yaml',
    `$ openapi read ./openapi.yml -f json > openapi.json`,
];
Read.flags = Object.assign({}, commonFlags.help(), commonFlags.parseOpts(), commonFlags.outputFormat());
Read.args = [
    {
        name: 'definition',
        description: 'input definition file',
        required: true,
    },
];
exports.default = Read;
