"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs");
const path = require("path");
const Router = require("koa-router");
const serve = require("koa-static");
const axios_1 = require("axios");
const utils_1 = require("../common/utils");
const commonFlags = require("../common/flags");
const koa_1 = require("../common/koa");
function getAbsoluteFSPath() {
    return path.dirname(require.resolve('swagger-editor-dist'));
}
class SwaggerEditor extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(SwaggerEditor);
        const { definition } = args;
        const { port, logger } = flags;
        const app = koa_1.createServer({ logger });
        const router = new Router();
        let document = null;
        if (definition) {
            if (definition.match('://')) {
                const { data } = await axios_1.default.get(definition);
                document = data;
            }
            else {
                document = fs.readFileSync(definition);
            }
        }
        const swaggerEditorRoot = getAbsoluteFSPath();
        if (document) {
            const indexHTML = fs.readFileSync(path.join(swaggerEditorRoot, 'index.html')).toString('utf8');
            router.get('/', (ctx) => {
                ctx.body = indexHTML.replace('window.editor = editor', `editor.specActions.updateSpec(\`${utils_1.escapeStringTemplateTicks(document.toString())}\`)\n\nwindow.editor = editor`);
            });
        }
        app.use(router.routes());
        app.use(serve(swaggerEditorRoot));
        const { port: portRunning } = await koa_1.startServer({ app, port });
        this.log(`Swagger Editor running at http://localhost:${portRunning}`);
        this.log();
    }
}
SwaggerEditor.description = 'serve a local Swagger UI instance';
SwaggerEditor.examples = [
    '$ openapi swagger-editor',
    '$ openapi swagger-editor ./openapi.yml',
    '$ openapi swagger-editor ./openapi.yml --bundle static',
];
SwaggerEditor.flags = Object.assign({}, commonFlags.help(), commonFlags.serverOpts());
SwaggerEditor.args = [
    {
        name: 'definition',
        description: 'input definition file',
    },
];
exports.default = SwaggerEditor;
