"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const s2o = require("swagger2openapi");
const util_1 = require("util");
const commonFlags = require("../common/flags");
const definition_1 = require("../common/definition");
class Swagger2Openapi extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Swagger2Openapi);
        // parse definition
        const { definition } = args;
        const { dereference, validate } = flags;
        const swagger = await definition_1.parseDefinition({ definition, dereference, validate });
        // convert to swagger
        let document;
        try {
            const convertOptions = {}; // @TODO: take in some flags?
            const converted = await util_1.promisify(s2o.convertObj)(swagger, convertOptions);
            document = converted.openapi;
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        // output in correct format
        const format = flags.format === 'json' || flags.json ? definition_1.OutputFormat.JSON : definition_1.OutputFormat.YAML;
        this.log(definition_1.stringifyDocument({ document, format }));
    }
}
Swagger2Openapi.description = 'convert Swagger 2.0 definitions to OpenAPI 3.0.x';
Swagger2Openapi.examples = [`$ openapi swagger2openapi --yaml ./swagger.json > openapi.yml`];
Swagger2Openapi.flags = Object.assign({}, commonFlags.help(), commonFlags.parseOpts(), commonFlags.outputFormat());
Swagger2Openapi.args = [
    {
        name: 'definition',
        description: 'input definition file',
        required: true,
    },
];
exports.default = Swagger2Openapi;
