"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SwaggerParser = require("swagger-parser");
const YAML = require("js-yaml");
async function parseDefinition({ definition, dereference, validate, servers, }) {
    let method = SwaggerParser.parse;
    if (dereference) {
        method = SwaggerParser.dereference;
    }
    if (validate) {
        method = SwaggerParser.validate;
    }
    const document = await method.bind(SwaggerParser)(definition);
    // add servers
    if (servers) {
        const serverObjects = servers.map((url) => ({ url }));
        document.servers = document.servers ? [...document.servers, ...serverObjects] : serverObjects;
    }
    return document;
}
exports.parseDefinition = parseDefinition;
var OutputFormat;
(function (OutputFormat) {
    OutputFormat["JSON"] = "json";
    OutputFormat["YAML"] = "yaml";
})(OutputFormat = exports.OutputFormat || (exports.OutputFormat = {}));
function stringifyDocument({ document, format }) {
    if (format === OutputFormat.JSON) {
        // JSON output
        return JSON.stringify(document, null, 2);
    }
    else {
        // YAML output
        return YAML.safeDump(document, { noRefs: true, lineWidth: 240, noArrayIndent: true });
    }
}
exports.stringifyDocument = stringifyDocument;
