"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const URL = require("url");
const fs = require("fs");
const path = require("path");
const Koa = require("koa");
const Router = require("koa-router");
const serve = require("koa-static");
const SwaggerUIDist = require("swagger-ui-dist");
exports.swaggerUIRoot = SwaggerUIDist.getAbsoluteFSPath();
var DocExpansion;
(function (DocExpansion) {
    DocExpansion["Full"] = "full";
    DocExpansion["List"] = "list";
    DocExpansion["None"] = "none";
})(DocExpansion = exports.DocExpansion || (exports.DocExpansion = {}));
function serveSwaggerUI(opts = {}) {
    const app = new Koa();
    const router = new Router();
    const indexHTML = getSwaggerUIIndexHTML(opts);
    // serve index.html
    router.get('/', (ctx) => {
        const url = ctx.originalUrl || ctx.url;
        const { pathname, query, hash } = URL.parse(url);
        // append trailing slash so relative paths work
        if (!pathname.endsWith('/')) {
            ctx.status = 302;
            return ctx.redirect(URL.format({
                pathname: `${pathname}/`,
                query,
                hash,
            }));
        }
        ctx.body = indexHTML;
        ctx.status = 200;
    });
    app.use(router.routes());
    app.use(serve(exports.swaggerUIRoot));
    return app;
}
exports.serveSwaggerUI = serveSwaggerUI;
function getSwaggerUIIndexHTML(opts = {}) {
    const config = Object.assign({ layout: 'StandaloneLayout', deepLinking: true, displayOperationId: true, displayRequestDuration: true, showExtensions: true, showCommonExtensions: true, withCredentials: true, filter: true }, opts);
    // modify index.html
    let indexHTML = fs
        .readFileSync(path.join(exports.swaggerUIRoot, 'index.html'))
        .toString('utf8')
        // apply our custom opts
        .replace('window.onload', `const config = JSON.parse(\'${JSON.stringify(config)}\');window.onload`)
        .replace('layout: "StandaloneLayout"', '...config');
    return indexHTML;
}
exports.getSwaggerUIIndexHTML = getSwaggerUIIndexHTML;
